import type { Metadata } from 'next'
import { Inter } from 'next/font/google'
import { ReactElement } from 'react'
import { I18nProviderClient } from '@/locales/client'
import { lc } from '@/lib/utils'
import './globals.css'
import { SessionProvider } from 'next-auth/react'
import { auth } from '@/config/auth'

const inter = Inter({ subsets: ['cyrillic'] })

export const metadata: Metadata = {
  title: 'Create Next App', description: 'Generated by create next app',
}

type RootLayoutProps = {
  params: { locale: string }; children: ReactElement;
}

export default async function RootLayout ({ params: { locale }, children }: Readonly<RootLayoutProps>) {
  const session = await auth()

  return (<SessionProvider session={session}>
    <html lang={lc(locale)?.java}>
    <body className={inter.className}>
    <I18nProviderClient locale={locale} fallback="Loading...">
      {children}
    </I18nProviderClient>
    </body>
    </html>
  </SessionProvider>)
}
